@@ -8,8 +8,8 @@ from wagtail.core.models import Locale, Page
 from wagtail.tests.utils import WagtailTestUtils
 
 from wagtail_localize.models import Translation, TranslationSource
-from wagtail_localize.test.models import TestPage
 from wagtail_localize_git.models import Resource, SyncLog, SyncLogResource
+from wagtail_localize_git.test.models import TestPage
 
 
 def create_test_page(**kwargs):
